"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

A domain for letting clients substitute browser's network layer with client code.
https://chromedevtools.github.io/devtools-protocol/tot/Fetch/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    Fetch,
    Network,
    Page,
)
from cdpkit.protocol.base import CDPEvent


class RequestPaused(CDPEvent):
    """ Issued when the domain is enabled and the request URL matches the
    specified filter. The request is paused until the client responds
    with one of continueRequest, failRequest or fulfillRequest.
    The stage of the request can be determined by presence of responseErrorReason
    and responseStatusCode -- the request is at the response stage if either
    of these fields is present and in the request stage otherwise.
    Redirect responses and subsequent requests are reported similarly to regular
    responses and requests. Redirect responses may be distinguished by the value
    of `responseStatusCode` (which is one of 301, 302, 303, 307, 308) along with
    presence of the `location` header. Requests resulting from a redirect will
    have `redirectedRequestId` field set. """

    requestId: Fetch.RequestId
    request: Network.Request
    frameId: Page.FrameId
    resourceType: Network.ResourceType
    responseErrorReason: Network.ErrorReason | None = None
    responseStatusCode: int | None = None
    responseStatusText: str | None = None
    responseHeaders: list[Fetch.HeaderEntry] | None = None
    networkId: Network.RequestId | None = None
    redirectedRequestId: Fetch.RequestId | None = None  # experimental


class AuthRequired(CDPEvent):
    """ Issued when the domain is enabled with handleAuthRequests set to true.
    The request is paused until client responds with continueWithAuth. """

    requestId: Fetch.RequestId
    request: Network.Request
    frameId: Page.FrameId
    resourceType: Network.ResourceType
    authChallenge: Fetch.AuthChallenge



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain allows inspection of Web Audio API.
https://webaudio.github.io/web-audio-api/
https://chromedevtools.github.io/devtools-protocol/tot/WebAudio/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    WebAudioAudioListener,
    WebAudioAudioNode,
    WebAudioAudioParam,
    WebAudioAutomationRate,
    WebAudioBaseAudioContext,
    WebAudioChannelCountMode,
    WebAudioChannelInterpretation,
    WebAudioContextRealtimeData,
    WebAudioContextState,
    WebAudioContextType,
    WebAudioGraphObjectId,
    WebAudioNodeType,
    WebAudioParamType,
)

GraphObjectId = WebAudioGraphObjectId
ContextType = WebAudioContextType
ContextState = WebAudioContextState
NodeType = WebAudioNodeType
ChannelCountMode = WebAudioChannelCountMode
ChannelInterpretation = WebAudioChannelInterpretation
ParamType = WebAudioParamType
AutomationRate = WebAudioAutomationRate
ContextRealtimeData = WebAudioContextRealtimeData
BaseAudioContext = WebAudioBaseAudioContext
AudioListener = WebAudioAudioListener
AudioNode = WebAudioAudioNode
AudioParam = WebAudioAudioParam



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain is deprecated - use Runtime or Log instead.
https://chromedevtools.github.io/devtools-protocol/tot/Console/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    ConsoleConsoleMessage,
)

ConsoleMessage = ConsoleConsoleMessage



from .events import ConsoleProfileFinished, ConsoleProfileStarted, PreciseCoverageDeltaUpdate
from .methods import (
    Disable,
    Enable,
    GetBestEffortCoverage,
    SetSamplingInterval,
    Start,
    StartPreciseCoverage,
    Stop,
    StopPreciseCoverage,
    TakePreciseCoverage,
)
from .types import CoverageRange, FunctionCoverage, PositionTickInfo, Profile, ProfileNode, ScriptCoverage

__all__ = [
    ProfileNode,
    Profile,
    PositionTickInfo,
    CoverageRange,
    FunctionCoverage,
    ScriptCoverage,
    ConsoleProfileFinished,
    ConsoleProfileStarted,
    PreciseCoverageDeltaUpdate,
    Disable,
    Enable,
    GetBestEffortCoverage,
    SetSamplingInterval,
    Start,
    StartPreciseCoverage,
    Stop,
    StopPreciseCoverage,
    TakePreciseCoverage,
]



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain allows interacting with the FedCM dialog.
https://chromedevtools.github.io/devtools-protocol/tot/FedCm/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    FedCmAccount,
    FedCmAccountUrlType,
    FedCmDialogButton,
    FedCmDialogType,
    FedCmLoginState,
)

LoginState = FedCmLoginState
DialogType = FedCmDialogType
DialogButton = FedCmDialogButton
AccountUrlType = FedCmAccountUrlType
Account = FedCmAccount



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/Input/

***************************************************
                    Methods
***************************************************
"""
from __future__ import annotations

from typing import Literal

from cdpkit.protocol._types import (
    Input,
)
from cdpkit.protocol.base import CDPMethod, InputModel


class DispatchDragEventInput(InputModel):

    type: Literal['dragEnter', 'dragOver', 'drop', 'dragCancel']
    x: float
    y: float
    data: Input.DragData
    modifiers: int | None = None


class DispatchDragEvent(CDPMethod[None]):  # experimental
    """ Dispatches a drag event into the page. """

    INPUT_VALIDATOR = DispatchDragEventInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        type_: Literal['dragEnter', 'dragOver', 'drop', 'dragCancel'],
        x: float,
        y: float,
        data: Input.DragData,
        modifiers: int | None = None
    ):
        super().__init__(
            type=type_,
            x=x,
            y=y,
            data=data,
            modifiers=modifiers
        )


class DispatchKeyEventInput(InputModel):

    type: Literal['keyDown', 'keyUp', 'rawKeyDown', 'char']
    modifiers: int | None = None
    timestamp: Input.TimeSinceEpoch | None = None
    text: str | None = None
    unmodifiedText: str | None = None
    keyIdentifier: str | None = None
    code: str | None = None
    key: str | None = None
    windowsVirtualKeyCode: int | None = None
    nativeVirtualKeyCode: int | None = None
    autoRepeat: bool | None = None
    isKeypad: bool | None = None
    isSystemKey: bool | None = None
    location: int | None = None
    commands: list[str] | None = None  # experimental


class DispatchKeyEvent(CDPMethod[None]):
    """ Dispatches a key event to the page. """

    INPUT_VALIDATOR = DispatchKeyEventInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        type_: Literal['keyDown', 'keyUp', 'rawKeyDown', 'char'],
        modifiers: int | None = None,
        timestamp: Input.TimeSinceEpoch | None = None,
        text: str | None = None,
        unmodified_text: str | None = None,
        key_identifier: str | None = None,
        code: str | None = None,
        key: str | None = None,
        windows_virtual_key_code: int | None = None,
        native_virtual_key_code: int | None = None,
        auto_repeat: bool | None = None,
        is_keypad: bool | None = None,
        is_system_key: bool | None = None,
        location: int | None = None,
        commands: list[str] | None = None
    ):
        super().__init__(
            type=type_,
            modifiers=modifiers,
            timestamp=timestamp,
            text=text,
            unmodifiedText=unmodified_text,
            keyIdentifier=key_identifier,
            code=code,
            key=key,
            windowsVirtualKeyCode=windows_virtual_key_code,
            nativeVirtualKeyCode=native_virtual_key_code,
            autoRepeat=auto_repeat,
            isKeypad=is_keypad,
            isSystemKey=is_system_key,
            location=location,
            commands=commands
        )


class InsertTextInput(InputModel):

    text: str


class InsertText(CDPMethod[None]):  # experimental
    """ This method emulates inserting text that doesn't come from a key press,
    for example an emoji keyboard or an IME. """

    INPUT_VALIDATOR = InsertTextInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        text: str
    ):
        super().__init__(
            text=text
        )


class ImeSetCompositionInput(InputModel):

    text: str
    selectionStart: int
    selectionEnd: int
    replacementStart: int | None = None
    replacementEnd: int | None = None


class ImeSetComposition(CDPMethod[None]):  # experimental
    """ This method sets the current candidate text for IME.
    Use imeCommitComposition to commit the final text.
    Use imeSetComposition with empty string as text to cancel composition. """

    INPUT_VALIDATOR = ImeSetCompositionInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        text: str,
        selection_start: int,
        selection_end: int,
        replacement_start: int | None = None,
        replacement_end: int | None = None
    ):
        super().__init__(
            text=text,
            selectionStart=selection_start,
            selectionEnd=selection_end,
            replacementStart=replacement_start,
            replacementEnd=replacement_end
        )


class DispatchMouseEventInput(InputModel):

    type: Literal['mousePressed', 'mouseReleased', 'mouseMoved', 'mouseWheel']
    x: float
    y: float
    modifiers: int | None = None
    timestamp: Input.TimeSinceEpoch | None = None
    button: Input.MouseButton | None = None
    buttons: int | None = None
    clickCount: int | None = None
    force: float | None = None  # experimental
    tangentialPressure: float | None = None  # experimental
    tiltX: float | None = None
    tiltY: float | None = None
    twist: int | None = None  # experimental
    deltaX: float | None = None
    deltaY: float | None = None
    pointerType: Literal['mouse', 'pen'] | None = None


class DispatchMouseEvent(CDPMethod[None]):
    """ Dispatches a mouse event to the page. """

    INPUT_VALIDATOR = DispatchMouseEventInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        type_: Literal['mousePressed', 'mouseReleased', 'mouseMoved', 'mouseWheel'],
        x: float,
        y: float,
        modifiers: int | None = None,
        timestamp: Input.TimeSinceEpoch | None = None,
        button: Input.MouseButton | None = None,
        buttons: int | None = None,
        click_count: int | None = None,
        force: float | None = None,
        tangential_pressure: float | None = None,
        tilt_x: float | None = None,
        tilt_y: float | None = None,
        twist: int | None = None,
        delta_x: float | None = None,
        delta_y: float | None = None,
        pointer_type: Literal['mouse', 'pen'] | None = None
    ):
        super().__init__(
            type=type_,
            x=x,
            y=y,
            modifiers=modifiers,
            timestamp=timestamp,
            button=button,
            buttons=buttons,
            clickCount=click_count,
            force=force,
            tangentialPressure=tangential_pressure,
            tiltX=tilt_x,
            tiltY=tilt_y,
            twist=twist,
            deltaX=delta_x,
            deltaY=delta_y,
            pointerType=pointer_type
        )


class DispatchTouchEventInput(InputModel):

    type: Literal['touchStart', 'touchEnd', 'touchMove', 'touchCancel']
    touchPoints: list[Input.TouchPoint]
    modifiers: int | None = None
    timestamp: Input.TimeSinceEpoch | None = None


class DispatchTouchEvent(CDPMethod[None]):
    """ Dispatches a touch event to the page. """

    INPUT_VALIDATOR = DispatchTouchEventInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        type_: Literal['touchStart', 'touchEnd', 'touchMove', 'touchCancel'],
        touch_points: list[Input.TouchPoint],
        modifiers: int | None = None,
        timestamp: Input.TimeSinceEpoch | None = None
    ):
        super().__init__(
            type=type_,
            touchPoints=touch_points,
            modifiers=modifiers,
            timestamp=timestamp
        )


class CancelDragging(CDPMethod[None]):
    """ Cancels any active dragging in the page. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class EmulateTouchFromMouseEventInput(InputModel):

    type: Literal['mousePressed', 'mouseReleased', 'mouseMoved', 'mouseWheel']
    x: int
    y: int
    button: Input.MouseButton
    timestamp: Input.TimeSinceEpoch | None = None
    deltaX: float | None = None
    deltaY: float | None = None
    modifiers: int | None = None
    clickCount: int | None = None


class EmulateTouchFromMouseEvent(CDPMethod[None]):  # experimental
    """ Emulates touch event from the mouse event parameters. """

    INPUT_VALIDATOR = EmulateTouchFromMouseEventInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        type_: Literal['mousePressed', 'mouseReleased', 'mouseMoved', 'mouseWheel'],
        x: int,
        y: int,
        button: Input.MouseButton,
        timestamp: Input.TimeSinceEpoch | None = None,
        delta_x: float | None = None,
        delta_y: float | None = None,
        modifiers: int | None = None,
        click_count: int | None = None
    ):
        super().__init__(
            type=type_,
            x=x,
            y=y,
            button=button,
            timestamp=timestamp,
            deltaX=delta_x,
            deltaY=delta_y,
            modifiers=modifiers,
            clickCount=click_count
        )


class SetIgnoreInputEventsInput(InputModel):

    ignore: bool


class SetIgnoreInputEvents(CDPMethod[None]):
    """ Ignores input events (useful while auditing page). """

    INPUT_VALIDATOR = SetIgnoreInputEventsInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        ignore: bool
    ):
        super().__init__(
            ignore=ignore
        )


class SetInterceptDragsInput(InputModel):

    enabled: bool


class SetInterceptDrags(CDPMethod[None]):  # experimental
    """ Prevents default drag and drop behavior and instead emits `Input.dragIntercepted` events.
    Drag and drop behavior can be directly controlled via `Input.dispatchDragEvent`. """

    INPUT_VALIDATOR = SetInterceptDragsInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        enabled: bool
    ):
        super().__init__(
            enabled=enabled
        )


class SynthesizePinchGestureInput(InputModel):

    x: float
    y: float
    scaleFactor: float
    relativeSpeed: int | None = None
    gestureSourceType: Input.GestureSourceType | None = None


class SynthesizePinchGesture(CDPMethod[None]):  # experimental
    """ Synthesizes a pinch gesture over a time period by issuing appropriate touch events. """

    INPUT_VALIDATOR = SynthesizePinchGestureInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        x: float,
        y: float,
        scale_factor: float,
        relative_speed: int | None = None,
        gesture_source_type: Input.GestureSourceType | None = None
    ):
        super().__init__(
            x=x,
            y=y,
            scaleFactor=scale_factor,
            relativeSpeed=relative_speed,
            gestureSourceType=gesture_source_type
        )


class SynthesizeScrollGestureInput(InputModel):

    x: float
    y: float
    xDistance: float | None = None
    yDistance: float | None = None
    xOverscroll: float | None = None
    yOverscroll: float | None = None
    preventFling: bool | None = None
    speed: int | None = None
    gestureSourceType: Input.GestureSourceType | None = None
    repeatCount: int | None = None
    repeatDelayMs: int | None = None
    interactionMarkerName: str | None = None


class SynthesizeScrollGesture(CDPMethod[None]):  # experimental
    """ Synthesizes a scroll gesture over a time period by issuing appropriate touch events. """

    INPUT_VALIDATOR = SynthesizeScrollGestureInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        x: float,
        y: float,
        x_distance: float | None = None,
        y_distance: float | None = None,
        x_overscroll: float | None = None,
        y_overscroll: float | None = None,
        prevent_fling: bool | None = None,
        speed: int | None = None,
        gesture_source_type: Input.GestureSourceType | None = None,
        repeat_count: int | None = None,
        repeat_delay_ms: int | None = None,
        interaction_marker_name: str | None = None
    ):
        super().__init__(
            x=x,
            y=y,
            xDistance=x_distance,
            yDistance=y_distance,
            xOverscroll=x_overscroll,
            yOverscroll=y_overscroll,
            preventFling=prevent_fling,
            speed=speed,
            gestureSourceType=gesture_source_type,
            repeatCount=repeat_count,
            repeatDelayMs=repeat_delay_ms,
            interactionMarkerName=interaction_marker_name
        )


class SynthesizeTapGestureInput(InputModel):

    x: float
    y: float
    duration: int | None = None
    tapCount: int | None = None
    gestureSourceType: Input.GestureSourceType | None = None


class SynthesizeTapGesture(CDPMethod[None]):  # experimental
    """ Synthesizes a tap gesture over a time period by issuing appropriate touch events. """

    INPUT_VALIDATOR = SynthesizeTapGestureInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        x: float,
        y: float,
        duration: int | None = None,
        tap_count: int | None = None,
        gesture_source_type: Input.GestureSourceType | None = None
    ):
        super().__init__(
            x=x,
            y=y,
            duration=duration,
            tapCount=tap_count,
            gestureSourceType=gesture_source_type
        )



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/Animation/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    AnimationAnimation,
    AnimationAnimationEffect,
    AnimationKeyframesRule,
    AnimationKeyframeStyle,
    AnimationViewOrScrollTimeline,
)

Animation = AnimationAnimation
ViewOrScrollTimeline = AnimationViewOrScrollTimeline
AnimationEffect = AnimationAnimationEffect
KeyframesRule = AnimationKeyframesRule
KeyframeStyle = AnimationKeyframeStyle



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/Preload/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    PreloadPrefetchStatus,
    PreloadPreloadingAttemptKey,
    PreloadPreloadingAttemptSource,
    PreloadPreloadingStatus,
    PreloadPreloadPipelineId,
    PreloadPrerenderFinalStatus,
    PreloadPrerenderMismatchedHeaders,
    PreloadRuleSet,
    PreloadRuleSetErrorType,
    PreloadRuleSetId,
    PreloadSpeculationAction,
    PreloadSpeculationTargetHint,
)

RuleSetId = PreloadRuleSetId
RuleSet = PreloadRuleSet
RuleSetErrorType = PreloadRuleSetErrorType
SpeculationAction = PreloadSpeculationAction
SpeculationTargetHint = PreloadSpeculationTargetHint
PreloadingAttemptKey = PreloadPreloadingAttemptKey
PreloadingAttemptSource = PreloadPreloadingAttemptSource
PreloadPipelineId = PreloadPreloadPipelineId
PrerenderFinalStatus = PreloadPrerenderFinalStatus
PreloadingStatus = PreloadPreloadingStatus
PrefetchStatus = PreloadPrefetchStatus
PrerenderMismatchedHeaders = PreloadPrerenderMismatchedHeaders



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Provides access to log entries.
https://chromedevtools.github.io/devtools-protocol/tot/Log/

***************************************************
                    Methods
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    Log,
)
from cdpkit.protocol.base import CDPMethod, InputModel


class Clear(CDPMethod[None]):
    """ Clears the log. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class Disable(CDPMethod[None]):
    """ Disables log domain, prevents further log entries from being reported to the client. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class Enable(CDPMethod[None]):
    """ Enables log domain, sends the entries collected so far to the client by means of the
    `entryAdded` notification. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class StartViolationsReportInput(InputModel):

    config: list[Log.ViolationSetting]


class StartViolationsReport(CDPMethod[None]):
    """ start violation reporting. """

    INPUT_VALIDATOR = StartViolationsReportInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        config: list[Log.ViolationSetting]
    ):
        super().__init__(
            config=config
        )


class StopViolationsReport(CDPMethod[None]):
    """ Stop violation reporting. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/Accessibility/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    Accessibility,
)
from cdpkit.protocol.base import CDPEvent


class LoadComplete(CDPEvent):
    """ The loadComplete event mirrors the load complete event sent by the browser to assistive
    technology when the web page has finished loading. """

    root: Accessibility.AXNode


class NodesUpdated(CDPEvent):
    """ The nodesUpdated event is sent every time a previously requested node has changed the in tree. """

    nodes: list[Accessibility.AXNode]



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/Accessibility/

***************************************************
                    Methods
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    DOM,
    Accessibility,
    Page,
    Runtime,
)
from cdpkit.protocol.base import CDPMethod, InputModel, OutputModel


class Disable(CDPMethod[None]):
    """ Disables the accessibility domain. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class Enable(CDPMethod[None]):
    """ Enables the accessibility domain which causes `AXNodeId`s to remain consistent between method calls.
    This turns on accessibility for the page, which can impact performance until accessibility is disabled. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class GetPartialAXTreeInput(InputModel):

    nodeId: DOM.NodeId | None = None
    backendNodeId: DOM.BackendNodeId | None = None
    objectId: Runtime.RemoteObjectId | None = None
    fetchRelatives: bool | None = None


class GetPartialAXTreeOutput(OutputModel):

    nodes: list[Accessibility.AXNode]


class GetPartialAXTree(CDPMethod[GetPartialAXTreeOutput]):  # experimental
    """ Fetches the accessibility node and partial accessibility tree for this DOM node, if it exists. """

    INPUT_VALIDATOR = GetPartialAXTreeInput
    OUTPUT_VALIDATOR = GetPartialAXTreeOutput

    def __init__(
        self,
        *,
        node_id: DOM.NodeId | None = None,
        backend_node_id: DOM.BackendNodeId | None = None,
        object_id: Runtime.RemoteObjectId | None = None,
        fetch_relatives: bool | None = None
    ):
        super().__init__(
            nodeId=node_id,
            backendNodeId=backend_node_id,
            objectId=object_id,
            fetchRelatives=fetch_relatives
        )


class GetFullAXTreeInput(InputModel):

    depth: int | None = None
    frameId: Page.FrameId | None = None


class GetFullAXTreeOutput(OutputModel):

    nodes: list[Accessibility.AXNode]


class GetFullAXTree(CDPMethod[GetFullAXTreeOutput]):  # experimental
    """ Fetches the entire accessibility tree for the root Document """

    INPUT_VALIDATOR = GetFullAXTreeInput
    OUTPUT_VALIDATOR = GetFullAXTreeOutput

    def __init__(
        self,
        *,
        depth: int | None = None,
        frame_id: Page.FrameId | None = None
    ):
        super().__init__(
            depth=depth,
            frameId=frame_id
        )


class GetRootAXNodeInput(InputModel):

    frameId: Page.FrameId | None = None


class GetRootAXNodeOutput(OutputModel):

    node: Accessibility.AXNode


class GetRootAXNode(CDPMethod[GetRootAXNodeOutput]):  # experimental
    """ Fetches the root node.
    Requires `enable()` to have been called previously. """

    INPUT_VALIDATOR = GetRootAXNodeInput
    OUTPUT_VALIDATOR = GetRootAXNodeOutput

    def __init__(
        self,
        *,
        frame_id: Page.FrameId | None = None
    ):
        super().__init__(
            frameId=frame_id
        )


class GetAXNodeAndAncestorsInput(InputModel):

    nodeId: DOM.NodeId | None = None
    backendNodeId: DOM.BackendNodeId | None = None
    objectId: Runtime.RemoteObjectId | None = None


class GetAXNodeAndAncestorsOutput(OutputModel):

    nodes: list[Accessibility.AXNode]


class GetAXNodeAndAncestors(CDPMethod[GetAXNodeAndAncestorsOutput]):  # experimental
    """ Fetches a node and all ancestors up to and including the root.
    Requires `enable()` to have been called previously. """

    INPUT_VALIDATOR = GetAXNodeAndAncestorsInput
    OUTPUT_VALIDATOR = GetAXNodeAndAncestorsOutput

    def __init__(
        self,
        *,
        node_id: DOM.NodeId | None = None,
        backend_node_id: DOM.BackendNodeId | None = None,
        object_id: Runtime.RemoteObjectId | None = None
    ):
        super().__init__(
            nodeId=node_id,
            backendNodeId=backend_node_id,
            objectId=object_id
        )


class GetChildAXNodesInput(InputModel):

    id: Accessibility.AXNodeId
    frameId: Page.FrameId | None = None


class GetChildAXNodesOutput(OutputModel):

    nodes: list[Accessibility.AXNode]


class GetChildAXNodes(CDPMethod[GetChildAXNodesOutput]):  # experimental
    """ Fetches a particular accessibility node by AXNodeId.
    Requires `enable()` to have been called previously. """

    INPUT_VALIDATOR = GetChildAXNodesInput
    OUTPUT_VALIDATOR = GetChildAXNodesOutput

    def __init__(
        self,
        *,
        id_: Accessibility.AXNodeId,
        frame_id: Page.FrameId | None = None
    ):
        super().__init__(
            id=id_,
            frameId=frame_id
        )


class QueryAXTreeInput(InputModel):

    nodeId: DOM.NodeId | None = None
    backendNodeId: DOM.BackendNodeId | None = None
    objectId: Runtime.RemoteObjectId | None = None
    accessibleName: str | None = None
    role: str | None = None


class QueryAXTreeOutput(OutputModel):

    nodes: list[Accessibility.AXNode]


class QueryAXTree(CDPMethod[QueryAXTreeOutput]):  # experimental
    """ Query a DOM node's accessibility subtree for accessible name and role.
    This command computes the name and role for all nodes in the subtree, including those that are
    ignored for accessibility, and returns those that match the specified name and role. If no DOM
    node is specified, or the DOM node does not exist, the command returns an error. If neither
    `accessibleName` or `role` is specified, it returns all the accessibility nodes in the subtree. """

    INPUT_VALIDATOR = QueryAXTreeInput
    OUTPUT_VALIDATOR = QueryAXTreeOutput

    def __init__(
        self,
        *,
        node_id: DOM.NodeId | None = None,
        backend_node_id: DOM.BackendNodeId | None = None,
        object_id: Runtime.RemoteObjectId | None = None,
        accessible_name: str | None = None,
        role: str | None = None
    ):
        super().__init__(
            nodeId=node_id,
            backendNodeId=backend_node_id,
            objectId=object_id,
            accessibleName=accessible_name,
            role=role
        )



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/Profiler/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    Debugger,
    Profiler,
)
from cdpkit.protocol.base import CDPEvent


class ConsoleProfileFinished(CDPEvent):

    id: str
    location: Debugger.Location
    profile: Profiler.Profile
    title: str | None = None


class ConsoleProfileStarted(CDPEvent):
    """ Sent when new profile recording is started using console.profile() call. """

    id: str
    location: Debugger.Location
    title: str | None = None


class PreciseCoverageDeltaUpdate(CDPEvent):
    """ Reports coverage delta since the last poll (either from an event like this, or from
    `takePreciseCoverage` for the current isolate. May only be sent if precise code
    coverage has been started. This event can be trigged by the embedder to, for example,
    trigger collection of coverage data immediately at a certain point in time. """

    timestamp: float
    occasion: str
    result: list[Profiler.ScriptCoverage]



from .base import CustomException


class ExecutableNotFoundError(CustomException):
    ERROR_INFO = 'Executable path not found, please check the settings.'


class NoSuchElement(CustomException):
    ERROR_INFO = 'No such element.'


class TabNotFoundError(CustomException):
    ERROR_INFO = 'Tab not found.'


class BrowserLaunchError(CustomException):
    ERROR_INFO = 'Browser launch error.'


class NoValidTabError(CustomException):
    ERROR_INFO = 'No valid tab available.'


class ElementNotFileInput(CustomException):
    ERROR_INFO = 'Element is not a file input.'


class ArgumentAlreadyExistsInOptions(CustomException):
    ERROR_INFO = 'Argument already exists in options.'


class ParamsMustSpecified(CustomException):
    ERROR_INFO = 'Params must specified.'


class ScriptRunError(CustomException):
    ERROR_INFO = 'Script run error.'



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain exposes CSS read/write operations. All CSS objects (stylesheets, rules, and styles)
have an associated `id` used in subsequent operations on the related object. Each object type has
a specific `id` structure, and those are not interchangeable between objects of different kinds.
CSS objects can be loaded using the `get*ForNode()` calls (which accept a DOM node id). A client
can also keep track of stylesheets via the `styleSheetAdded`/`styleSheetRemoved` events and
subsequently load the required stylesheet contents using the `getStyleSheet[Text]()` methods.
https://chromedevtools.github.io/devtools-protocol/tot/CSS/

***************************************************
                    Methods
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    CSS,
    DOM,
    Page,
)
from cdpkit.protocol.base import JSON_DICT, CDPMethod, InputModel, OutputModel


class AddRuleInput(InputModel):

    styleSheetId: DOM.StyleSheetId
    ruleText: str
    location: CSS.SourceRange
    nodeForPropertySyntaxValidation: DOM.NodeId | None = None  # experimental


class AddRuleOutput(OutputModel):

    rule: CSS.CSSRule


class AddRule(CDPMethod[AddRuleOutput]):
    """ Inserts a new rule with the given `ruleText` in a stylesheet with given `styleSheetId`, at the
    position specified by `location`. """

    INPUT_VALIDATOR = AddRuleInput
    OUTPUT_VALIDATOR = AddRuleOutput

    def __init__(
        self,
        *,
        style_sheet_id: DOM.StyleSheetId,
        rule_text: str,
        location: CSS.SourceRange,
        node_for_property_syntax_validation: DOM.NodeId | None = None
    ):
        super().__init__(
            styleSheetId=style_sheet_id,
            ruleText=rule_text,
            location=location,
            nodeForPropertySyntaxValidation=node_for_property_syntax_validation
        )


class CollectClassNamesInput(InputModel):

    styleSheetId: DOM.StyleSheetId


class CollectClassNamesOutput(OutputModel):

    classNames: list[str]


class CollectClassNames(CDPMethod[CollectClassNamesOutput]):
    """ Returns all class names from specified stylesheet. """

    INPUT_VALIDATOR = CollectClassNamesInput
    OUTPUT_VALIDATOR = CollectClassNamesOutput

    def __init__(
        self,
        *,
        style_sheet_id: DOM.StyleSheetId
    ):
        super().__init__(
            styleSheetId=style_sheet_id
        )


class CreateStyleSheetInput(InputModel):

    frameId: Page.FrameId
    force: bool | None = None


class CreateStyleSheetOutput(OutputModel):

    styleSheetId: DOM.StyleSheetId


class CreateStyleSheet(CDPMethod[CreateStyleSheetOutput]):
    """ Creates a new special "via-inspector" stylesheet in the frame with given `frameId`. """

    INPUT_VALIDATOR = CreateStyleSheetInput
    OUTPUT_VALIDATOR = CreateStyleSheetOutput

    def __init__(
        self,
        *,
        frame_id: Page.FrameId,
        force: bool | None = None
    ):
        super().__init__(
            frameId=frame_id,
            force=force
        )


class Disable(CDPMethod[None]):
    """ Disables the CSS agent for the given page. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class Enable(CDPMethod[None]):
    """ Enables the CSS agent for the given page. Clients should not assume that the CSS agent has been
    enabled until the result of this command is received. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class ForcePseudoStateInput(InputModel):

    nodeId: DOM.NodeId
    forcedPseudoClasses: list[str]


class ForcePseudoState(CDPMethod[None]):
    """ Ensures that the given node will have specified pseudo-classes whenever its style is computed by
    the browser. """

    INPUT_VALIDATOR = ForcePseudoStateInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        node_id: DOM.NodeId,
        forced_pseudo_classes: list[str]
    ):
        super().__init__(
            nodeId=node_id,
            forcedPseudoClasses=forced_pseudo_classes
        )


class ForceStartingStyleInput(InputModel):

    nodeId: DOM.NodeId
    forced: bool


class ForceStartingStyle(CDPMethod[None]):
    """ Ensures that the given node is in its starting-style state. """

    INPUT_VALIDATOR = ForceStartingStyleInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        node_id: DOM.NodeId,
        forced: bool
    ):
        super().__init__(
            nodeId=node_id,
            forced=forced
        )


class GetBackgroundColorsInput(InputModel):

    nodeId: DOM.NodeId


class GetBackgroundColorsOutput(OutputModel):

    backgroundColors: list[str] | None = None
    computedFontSize: str | None = None
    computedFontWeight: str | None = None


class GetBackgroundColors(CDPMethod[GetBackgroundColorsOutput]):

    INPUT_VALIDATOR = GetBackgroundColorsInput
    OUTPUT_VALIDATOR = GetBackgroundColorsOutput

    def __init__(
        self,
        *,
        node_id: DOM.NodeId
    ):
        super().__init__(
            nodeId=node_id
        )


class GetComputedStyleForNodeInput(InputModel):

    nodeId: DOM.NodeId


class GetComputedStyleForNodeOutput(OutputModel):

    computedStyle: list[CSS.CSSComputedStyleProperty]
    extraFields: CSS.ComputedStyleExtraFields | None = None  # experimental


class GetComputedStyleForNode(CDPMethod[GetComputedStyleForNodeOutput]):
    """ Returns the computed style for a DOM node identified by `nodeId`. """

    INPUT_VALIDATOR = GetComputedStyleForNodeInput
    OUTPUT_VALIDATOR = GetComputedStyleForNodeOutput

    def __init__(
        self,
        *,
        node_id: DOM.NodeId
    ):
        super().__init__(
            nodeId=node_id
        )


class ResolveValuesInput(InputModel):

    values: list[str]
    nodeId: DOM.NodeId
    propertyName: str | None = None
    pseudoType: DOM.PseudoType | None = None
    pseudoIdentifier: str | None = None


class ResolveValuesOutput(OutputModel):

    results: list[str]


class ResolveValues(CDPMethod[ResolveValuesOutput]):  # experimental
    """ Resolve the specified values in the context of the provided element.
    For example, a value of '1em' is evaluated according to the computed
    'font-size' of the element and a value 'calc(1px + 2px)' will be
    resolved to '3px'.
    If the `propertyName` was specified the `values` are resolved as if
    they were property's declaration. If a value cannot be parsed according
    to the provided property syntax, the value is parsed using combined
    syntax as if null `propertyName` was provided. If the value cannot be
    resolved even then, return the provided value without any changes. """

    INPUT_VALIDATOR = ResolveValuesInput
    OUTPUT_VALIDATOR = ResolveValuesOutput

    def __init__(
        self,
        *,
        values: list[str],
        node_id: DOM.NodeId,
        property_name: str | None = None,
        pseudo_type: DOM.PseudoType | None = None,
        pseudo_identifier: str | None = None
    ):
        super().__init__(
            values=values,
            nodeId=node_id,
            propertyName=property_name,
            pseudoType=pseudo_type,
            pseudoIdentifier=pseudo_identifier
        )


class GetLonghandPropertiesInput(InputModel):

    shorthandName: str
    value: str


class GetLonghandPropertiesOutput(OutputModel):

    longhandProperties: list[CSS.CSSProperty]


class GetLonghandProperties(CDPMethod[GetLonghandPropertiesOutput]):  # experimental

    INPUT_VALIDATOR = GetLonghandPropertiesInput
    OUTPUT_VALIDATOR = GetLonghandPropertiesOutput

    def __init__(
        self,
        *,
        shorthand_name: str,
        value: str
    ):
        super().__init__(
            shorthandName=shorthand_name,
            value=value
        )


class GetInlineStylesForNodeInput(InputModel):

    nodeId: DOM.NodeId


class GetInlineStylesForNodeOutput(OutputModel):

    inlineStyle: CSS.CSSStyle | None = None
    attributesStyle: CSS.CSSStyle | None = None


class GetInlineStylesForNode(CDPMethod[GetInlineStylesForNodeOutput]):
    """ Returns the styles defined inline (explicitly in the "style" attribute and implicitly, using DOM
    attributes) for a DOM node identified by `nodeId`. """

    INPUT_VALIDATOR = GetInlineStylesForNodeInput
    OUTPUT_VALIDATOR = GetInlineStylesForNodeOutput

    def __init__(
        self,
        *,
        node_id: DOM.NodeId
    ):
        super().__init__(
            nodeId=node_id
        )


class GetAnimatedStylesForNodeInput(InputModel):

    nodeId: DOM.NodeId


class GetAnimatedStylesForNodeOutput(OutputModel):

    animationStyles: list[CSS.CSSAnimationStyle] | None = None
    transitionsStyle: CSS.CSSStyle | None = None
    inherited: list[CSS.InheritedAnimatedStyleEntry] | None = None


class GetAnimatedStylesForNode(CDPMethod[GetAnimatedStylesForNodeOutput]):  # experimental
    """ Returns the styles coming from animations & transitions
    including the animation & transition styles coming from inheritance chain. """

    INPUT_VALIDATOR = GetAnimatedStylesForNodeInput
    OUTPUT_VALIDATOR = GetAnimatedStylesForNodeOutput

    def __init__(
        self,
        *,
        node_id: DOM.NodeId
    ):
        super().__init__(
            nodeId=node_id
        )


class GetMatchedStylesForNodeInput(InputModel):

    nodeId: DOM.NodeId


class GetMatchedStylesForNodeOutput(OutputModel):

    inlineStyle: CSS.CSSStyle | None = None
    attributesStyle: CSS.CSSStyle | None = None
    matchedCSSRules: list[CSS.RuleMatch] | None = None
    pseudoElements: list[CSS.PseudoElementMatches] | None = None
    inherited: list[CSS.InheritedStyleEntry] | None = None
    inheritedPseudoElements: list[CSS.InheritedPseudoElementMatches] | None = None
    cssKeyframesRules: list[CSS.CSSKeyframesRule] | None = None
    cssPositionTryRules: list[CSS.CSSPositionTryRule] | None = None
    activePositionFallbackIndex: int | None = None
    cssPropertyRules: list[CSS.CSSPropertyRule] | None = None
    cssPropertyRegistrations: list[CSS.CSSPropertyRegistration] | None = None
    cssAtRules: list[CSS.CSSAtRule] | None = None
    parentLayoutNodeId: DOM.NodeId | None = None  # experimental
    cssFunctionRules: list[CSS.CSSFunctionRule] | None = None  # experimental


class GetMatchedStylesForNode(CDPMethod[GetMatchedStylesForNodeOutput]):
    """ Returns requested styles for a DOM node identified by `nodeId`. """

    INPUT_VALIDATOR = GetMatchedStylesForNodeInput
    OUTPUT_VALIDATOR = GetMatchedStylesForNodeOutput

    def __init__(
        self,
        *,
        node_id: DOM.NodeId
    ):
        super().__init__(
            nodeId=node_id
        )


class GetEnvironmentVariablesOutput(OutputModel):

    environmentVariables: JSON_DICT


class GetEnvironmentVariables(CDPMethod[GetEnvironmentVariablesOutput]):  # experimental
    """ Returns the values of the default UA-defined environment variables used in env() """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = GetEnvironmentVariablesOutput


class GetMediaQueriesOutput(OutputModel):

    medias: list[CSS.CSSMedia]


class GetMediaQueries(CDPMethod[GetMediaQueriesOutput]):
    """ Returns all media queries parsed by the rendering engine. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = GetMediaQueriesOutput


class GetPlatformFontsForNodeInput(InputModel):

    nodeId: DOM.NodeId


class GetPlatformFontsForNodeOutput(OutputModel):

    fonts: list[CSS.PlatformFontUsage]


class GetPlatformFontsForNode(CDPMethod[GetPlatformFontsForNodeOutput]):
    """ Requests information about platform fonts which we used to render child TextNodes in the given
    node. """

    INPUT_VALIDATOR = GetPlatformFontsForNodeInput
    OUTPUT_VALIDATOR = GetPlatformFontsForNodeOutput

    def __init__(
        self,
        *,
        node_id: DOM.NodeId
    ):
        super().__init__(
            nodeId=node_id
        )


class GetStyleSheetTextInput(InputModel):

    styleSheetId: DOM.StyleSheetId


class GetStyleSheetTextOutput(OutputModel):

    text: str


class GetStyleSheetText(CDPMethod[GetStyleSheetTextOutput]):
    """ Returns the current textual content for a stylesheet. """

    INPUT_VALIDATOR = GetStyleSheetTextInput
    OUTPUT_VALIDATOR = GetStyleSheetTextOutput

    def __init__(
        self,
        *,
        style_sheet_id: DOM.StyleSheetId
    ):
        super().__init__(
            styleSheetId=style_sheet_id
        )


class GetLayersForNodeInput(InputModel):

    nodeId: DOM.NodeId


class GetLayersForNodeOutput(OutputModel):

    rootLayer: CSS.CSSLayerData


class GetLayersForNode(CDPMethod[GetLayersForNodeOutput]):  # experimental
    """ Returns all layers parsed by the rendering engine for the tree scope of a node.
    Given a DOM element identified by nodeId, getLayersForNode returns the root
    layer for the nearest ancestor document or shadow root. The layer root contains
    the full layer tree for the tree scope and their ordering. """

    INPUT_VALIDATOR = GetLayersForNodeInput
    OUTPUT_VALIDATOR = GetLayersForNodeOutput

    def __init__(
        self,
        *,
        node_id: DOM.NodeId
    ):
        super().__init__(
            nodeId=node_id
        )


class GetLocationForSelectorInput(InputModel):

    styleSheetId: DOM.StyleSheetId
    selectorText: str


class GetLocationForSelectorOutput(OutputModel):

    ranges: list[CSS.SourceRange]


class GetLocationForSelector(CDPMethod[GetLocationForSelectorOutput]):  # experimental
    """ Given a CSS selector text and a style sheet ID, getLocationForSelector
    returns an array of locations of the CSS selector in the style sheet. """

    INPUT_VALIDATOR = GetLocationForSelectorInput
    OUTPUT_VALIDATOR = GetLocationForSelectorOutput

    def __init__(
        self,
        *,
        style_sheet_id: DOM.StyleSheetId,
        selector_text: str
    ):
        super().__init__(
            styleSheetId=style_sheet_id,
            selectorText=selector_text
        )


class TrackComputedStyleUpdatesForNodeInput(InputModel):

    nodeId: DOM.NodeId | None = None


class TrackComputedStyleUpdatesForNode(CDPMethod[None]):  # experimental
    """ Starts tracking the given node for the computed style updates
    and whenever the computed style is updated for node, it queues
    a `computedStyleUpdated` event with throttling.
    There can only be 1 node tracked for computed style updates
    so passing a new node id removes tracking from the previous node.
    Pass `undefined` to disable tracking. """

    INPUT_VALIDATOR = TrackComputedStyleUpdatesForNodeInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        node_id: DOM.NodeId | None = None
    ):
        super().__init__(
            nodeId=node_id
        )


class TrackComputedStyleUpdatesInput(InputModel):

    propertiesToTrack: list[CSS.CSSComputedStyleProperty]


class TrackComputedStyleUpdates(CDPMethod[None]):  # experimental
    """ Starts tracking the given computed styles for updates. The specified array of properties
    replaces the one previously specified. Pass empty array to disable tracking.
    Use takeComputedStyleUpdates to retrieve the list of nodes that had properties modified.
    The changes to computed style properties are only tracked for nodes pushed to the front-end
    by the DOM agent. If no changes to the tracked properties occur after the node has been pushed
    to the front-end, no updates will be issued for the node. """

    INPUT_VALIDATOR = TrackComputedStyleUpdatesInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        properties_to_track: list[CSS.CSSComputedStyleProperty]
    ):
        super().__init__(
            propertiesToTrack=properties_to_track
        )


class TakeComputedStyleUpdatesOutput(OutputModel):

    nodeIds: list[DOM.NodeId]


class TakeComputedStyleUpdates(CDPMethod[TakeComputedStyleUpdatesOutput]):  # experimental
    """ Polls the next batch of computed style updates. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = TakeComputedStyleUpdatesOutput


class SetEffectivePropertyValueForNodeInput(InputModel):

    nodeId: DOM.NodeId
    propertyName: str
    value: str


class SetEffectivePropertyValueForNode(CDPMethod[None]):
    """ Find a rule with the given active property for the given node and set the new value for this
    property """

    INPUT_VALIDATOR = SetEffectivePropertyValueForNodeInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        node_id: DOM.NodeId,
        property_name: str,
        value: str
    ):
        super().__init__(
            nodeId=node_id,
            propertyName=property_name,
            value=value
        )


class SetPropertyRulePropertyNameInput(InputModel):

    styleSheetId: DOM.StyleSheetId
    range: CSS.SourceRange
    propertyName: str


class SetPropertyRulePropertyNameOutput(OutputModel):

    propertyName: CSS.Value


class SetPropertyRulePropertyName(CDPMethod[SetPropertyRulePropertyNameOutput]):
    """ Modifies the property rule property name. """

    INPUT_VALIDATOR = SetPropertyRulePropertyNameInput
    OUTPUT_VALIDATOR = SetPropertyRulePropertyNameOutput

    def __init__(
        self,
        *,
        style_sheet_id: DOM.StyleSheetId,
        range_: CSS.SourceRange,
        property_name: str
    ):
        super().__init__(
            styleSheetId=style_sheet_id,
            range=range_,
            propertyName=property_name
        )


class SetKeyframeKeyInput(InputModel):

    styleSheetId: DOM.StyleSheetId
    range: CSS.SourceRange
    keyText: str


class SetKeyframeKeyOutput(OutputModel):

    keyText: CSS.Value


class SetKeyframeKey(CDPMethod[SetKeyframeKeyOutput]):
    """ Modifies the keyframe rule key text. """

    INPUT_VALIDATOR = SetKeyframeKeyInput
    OUTPUT_VALIDATOR = SetKeyframeKeyOutput

    def __init__(
        self,
        *,
        style_sheet_id: DOM.StyleSheetId,
        range_: CSS.SourceRange,
        key_text: str
    ):
        super().__init__(
            styleSheetId=style_sheet_id,
            range=range_,
            keyText=key_text
        )


class SetMediaTextInput(InputModel):

    styleSheetId: DOM.StyleSheetId
    range: CSS.SourceRange
    text: str


class SetMediaTextOutput(OutputModel):

    media: CSS.CSSMedia


class SetMediaText(CDPMethod[SetMediaTextOutput]):
    """ Modifies the rule selector. """

    INPUT_VALIDATOR = SetMediaTextInput
    OUTPUT_VALIDATOR = SetMediaTextOutput

    def __init__(
        self,
        *,
        style_sheet_id: DOM.StyleSheetId,
        range_: CSS.SourceRange,
        text: str
    ):
        super().__init__(
            styleSheetId=style_sheet_id,
            range=range_,
            text=text
        )


class SetContainerQueryTextInput(InputModel):

    styleSheetId: DOM.StyleSheetId
    range: CSS.SourceRange
    text: str


class SetContainerQueryTextOutput(OutputModel):

    containerQuery: CSS.CSSContainerQuery


class SetContainerQueryText(CDPMethod[SetContainerQueryTextOutput]):  # experimental
    """ Modifies the expression of a container query. """

    INPUT_VALIDATOR = SetContainerQueryTextInput
    OUTPUT_VALIDATOR = SetContainerQueryTextOutput

    def __init__(
        self,
        *,
        style_sheet_id: DOM.StyleSheetId,
        range_: CSS.SourceRange,
        text: str
    ):
        super().__init__(
            styleSheetId=style_sheet_id,
            range=range_,
            text=text
        )


class SetSupportsTextInput(InputModel):

    styleSheetId: DOM.StyleSheetId
    range: CSS.SourceRange
    text: str


class SetSupportsTextOutput(OutputModel):

    supports: CSS.CSSSupports


class SetSupportsText(CDPMethod[SetSupportsTextOutput]):  # experimental
    """ Modifies the expression of a supports at-rule. """

    INPUT_VALIDATOR = SetSupportsTextInput
    OUTPUT_VALIDATOR = SetSupportsTextOutput

    def __init__(
        self,
        *,
        style_sheet_id: DOM.StyleSheetId,
        range_: CSS.SourceRange,
        text: str
    ):
        super().__init__(
            styleSheetId=style_sheet_id,
            range=range_,
            text=text
        )


class SetScopeTextInput(InputModel):

    styleSheetId: DOM.StyleSheetId
    range: CSS.SourceRange
    text: str


class SetScopeTextOutput(OutputModel):

    scope: CSS.CSSScope


class SetScopeText(CDPMethod[SetScopeTextOutput]):  # experimental
    """ Modifies the expression of a scope at-rule. """

    INPUT_VALIDATOR = SetScopeTextInput
    OUTPUT_VALIDATOR = SetScopeTextOutput

    def __init__(
        self,
        *,
        style_sheet_id: DOM.StyleSheetId,
        range_: CSS.SourceRange,
        text: str
    ):
        super().__init__(
            styleSheetId=style_sheet_id,
            range=range_,
            text=text
        )


class SetRuleSelectorInput(InputModel):

    styleSheetId: DOM.StyleSheetId
    range: CSS.SourceRange
    selector: str


class SetRuleSelectorOutput(OutputModel):

    selectorList: CSS.SelectorList


class SetRuleSelector(CDPMethod[SetRuleSelectorOutput]):
    """ Modifies the rule selector. """

    INPUT_VALIDATOR = SetRuleSelectorInput
    OUTPUT_VALIDATOR = SetRuleSelectorOutput

    def __init__(
        self,
        *,
        style_sheet_id: DOM.StyleSheetId,
        range_: CSS.SourceRange,
        selector: str
    ):
        super().__init__(
            styleSheetId=style_sheet_id,
            range=range_,
            selector=selector
        )


class SetStyleSheetTextInput(InputModel):

    styleSheetId: DOM.StyleSheetId
    text: str


class SetStyleSheetTextOutput(OutputModel):

    sourceMapURL: str | None = None


class SetStyleSheetText(CDPMethod[SetStyleSheetTextOutput]):
    """ Sets the new stylesheet text. """

    INPUT_VALIDATOR = SetStyleSheetTextInput
    OUTPUT_VALIDATOR = SetStyleSheetTextOutput

    def __init__(
        self,
        *,
        style_sheet_id: DOM.StyleSheetId,
        text: str
    ):
        super().__init__(
            styleSheetId=style_sheet_id,
            text=text
        )


class SetStyleTextsInput(InputModel):

    edits: list[CSS.StyleDeclarationEdit]
    nodeForPropertySyntaxValidation: DOM.NodeId | None = None  # experimental


class SetStyleTextsOutput(OutputModel):

    styles: list[CSS.CSSStyle]


class SetStyleTexts(CDPMethod[SetStyleTextsOutput]):
    """ Applies specified style edits one after another in the given order. """

    INPUT_VALIDATOR = SetStyleTextsInput
    OUTPUT_VALIDATOR = SetStyleTextsOutput

    def __init__(
        self,
        *,
        edits: list[CSS.StyleDeclarationEdit],
        node_for_property_syntax_validation: DOM.NodeId | None = None
    ):
        super().__init__(
            edits=edits,
            nodeForPropertySyntaxValidation=node_for_property_syntax_validation
        )


class StartRuleUsageTracking(CDPMethod[None]):
    """ Enables the selector recording. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class StopRuleUsageTrackingOutput(OutputModel):

    ruleUsage: list[CSS.RuleUsage]


class StopRuleUsageTracking(CDPMethod[StopRuleUsageTrackingOutput]):
    """ Stop tracking rule usage and return the list of rules that were used since last call to
    `takeCoverageDelta` (or since start of coverage instrumentation). """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = StopRuleUsageTrackingOutput


class TakeCoverageDeltaOutput(OutputModel):

    coverage: list[CSS.RuleUsage]
    timestamp: float


class TakeCoverageDelta(CDPMethod[TakeCoverageDeltaOutput]):
    """ Obtain list of rules that became used since last call to this method (or since start of coverage
    instrumentation). """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = TakeCoverageDeltaOutput


class SetLocalFontsEnabledInput(InputModel):

    enabled: bool


class SetLocalFontsEnabled(CDPMethod[None]):  # experimental
    """ Enables/disables rendering of local CSS fonts (enabled by default). """

    INPUT_VALIDATOR = SetLocalFontsEnabledInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        enabled: bool
    ):
        super().__init__(
            enabled=enabled
        )



from .events import (
    ComputedStyleUpdated,
    FontsUpdated,
    MediaQueryResultChanged,
    StyleSheetAdded,
    StyleSheetChanged,
    StyleSheetRemoved,
)
from .methods import (
    AddRule,
    CollectClassNames,
    CreateStyleSheet,
    Disable,
    Enable,
    ForcePseudoState,
    ForceStartingStyle,
    GetAnimatedStylesForNode,
    GetBackgroundColors,
    GetComputedStyleForNode,
    GetEnvironmentVariables,
    GetInlineStylesForNode,
    GetLayersForNode,
    GetLocationForSelector,
    GetLonghandProperties,
    GetMatchedStylesForNode,
    GetMediaQueries,
    GetPlatformFontsForNode,
    GetStyleSheetText,
    ResolveValues,
    SetContainerQueryText,
    SetEffectivePropertyValueForNode,
    SetKeyframeKey,
    SetLocalFontsEnabled,
    SetMediaText,
    SetPropertyRulePropertyName,
    SetRuleSelector,
    SetScopeText,
    SetStyleSheetText,
    SetStyleTexts,
    SetSupportsText,
    StartRuleUsageTracking,
    StopRuleUsageTracking,
    TakeComputedStyleUpdates,
    TakeCoverageDelta,
    TrackComputedStyleUpdates,
    TrackComputedStyleUpdatesForNode,
)
from .types import (
    ComputedStyleExtraFields,
    CSSAnimationStyle,
    CSSAtRule,
    CSSComputedStyleProperty,
    CSSContainerQuery,
    CSSFunctionConditionNode,
    CSSFunctionNode,
    CSSFunctionParameter,
    CSSFunctionRule,
    CSSKeyframeRule,
    CSSKeyframesRule,
    CSSLayer,
    CSSLayerData,
    CSSMedia,
    CSSPositionTryRule,
    CSSProperty,
    CSSPropertyRegistration,
    CSSPropertyRule,
    CSSRule,
    CSSRuleType,
    CSSScope,
    CSSStartingStyle,
    CSSStyle,
    CSSStyleSheetHeader,
    CSSSupports,
    CSSTryRule,
    FontFace,
    FontVariationAxis,
    InheritedAnimatedStyleEntry,
    InheritedPseudoElementMatches,
    InheritedStyleEntry,
    MediaQuery,
    MediaQueryExpression,
    PlatformFontUsage,
    PseudoElementMatches,
    RuleMatch,
    RuleUsage,
    SelectorList,
    ShorthandEntry,
    SourceRange,
    Specificity,
    StyleDeclarationEdit,
    StyleSheetOrigin,
    Value,
)

__all__ = [
    StyleSheetOrigin,
    PseudoElementMatches,
    CSSAnimationStyle,
    InheritedStyleEntry,
    InheritedAnimatedStyleEntry,
    InheritedPseudoElementMatches,
    RuleMatch,
    Value,
    Specificity,
    SelectorList,
    CSSStyleSheetHeader,
    CSSRule,
    CSSRuleType,
    RuleUsage,
    SourceRange,
    ShorthandEntry,
    CSSComputedStyleProperty,
    ComputedStyleExtraFields,
    CSSStyle,
    CSSProperty,
    CSSMedia,
    MediaQuery,
    MediaQueryExpression,
    CSSContainerQuery,
    CSSSupports,
    CSSScope,
    CSSLayer,
    CSSStartingStyle,
    CSSLayerData,
    PlatformFontUsage,
    FontVariationAxis,
    FontFace,
    CSSTryRule,
    CSSPositionTryRule,
    CSSKeyframesRule,
    CSSPropertyRegistration,
    CSSAtRule,
    CSSPropertyRule,
    CSSFunctionParameter,
    CSSFunctionConditionNode,
    CSSFunctionNode,
    CSSFunctionRule,
    CSSKeyframeRule,
    StyleDeclarationEdit,
    FontsUpdated,
    MediaQueryResultChanged,
    StyleSheetAdded,
    StyleSheetChanged,
    StyleSheetRemoved,
    ComputedStyleUpdated,
    AddRule,
    CollectClassNames,
    CreateStyleSheet,
    Disable,
    Enable,
    ForcePseudoState,
    ForceStartingStyle,
    GetBackgroundColors,
    GetComputedStyleForNode,
    ResolveValues,
    GetLonghandProperties,
    GetInlineStylesForNode,
    GetAnimatedStylesForNode,
    GetMatchedStylesForNode,
    GetEnvironmentVariables,
    GetMediaQueries,
    GetPlatformFontsForNode,
    GetStyleSheetText,
    GetLayersForNode,
    GetLocationForSelector,
    TrackComputedStyleUpdatesForNode,
    TrackComputedStyleUpdates,
    TakeComputedStyleUpdates,
    SetEffectivePropertyValueForNode,
    SetPropertyRulePropertyName,
    SetKeyframeKey,
    SetMediaText,
    SetContainerQueryText,
    SetSupportsText,
    SetScopeText,
    SetRuleSelector,
    SetStyleSheetText,
    SetStyleTexts,
    StartRuleUsageTracking,
    StopRuleUsageTracking,
    TakeCoverageDelta,
    SetLocalFontsEnabled,
]



from .events import IssueAdded
from .methods import CheckContrast, CheckFormsIssues, Disable, Enable, GetEncodedResponse
from .types import (
    AffectedCookie,
    AffectedFrame,
    AffectedRequest,
    AttributionReportingIssueDetails,
    AttributionReportingIssueType,
    BlockedByResponseIssueDetails,
    BlockedByResponseReason,
    BounceTrackingIssueDetails,
    ClientHintIssueDetails,
    ClientHintIssueReason,
    ContentSecurityPolicyIssueDetails,
    ContentSecurityPolicyViolationType,
    CookieDeprecationMetadataIssueDetails,
    CookieExclusionReason,
    CookieIssueDetails,
    CookieIssueInsight,
    CookieOperation,
    CookieWarningReason,
    CorsIssueDetails,
    DeprecationIssueDetails,
    ElementAccessibilityIssueDetails,
    ElementAccessibilityIssueReason,
    FailedRequestInfo,
    FederatedAuthRequestIssueDetails,
    FederatedAuthRequestIssueReason,
    FederatedAuthUserInfoRequestIssueDetails,
    FederatedAuthUserInfoRequestIssueReason,
    GenericIssueDetails,
    GenericIssueErrorType,
    HeavyAdIssueDetails,
    HeavyAdReason,
    HeavyAdResolutionStatus,
    InsightType,
    InspectorIssue,
    InspectorIssueCode,
    InspectorIssueDetails,
    IssueId,
    LowTextContrastIssueDetails,
    MixedContentIssueDetails,
    MixedContentResolutionStatus,
    MixedContentResourceType,
    NavigatorUserAgentIssueDetails,
    PartitioningBlobURLInfo,
    PartitioningBlobURLIssueDetails,
    PermissionElementIssueDetails,
    PermissionElementIssueType,
    PropertyRuleIssueDetails,
    PropertyRuleIssueReason,
    QuirksModeIssueDetails,
    SharedArrayBufferIssueDetails,
    SharedArrayBufferIssueType,
    SharedDictionaryError,
    SharedDictionaryIssueDetails,
    SourceCodeLocation,
    SRIMessageSignatureError,
    SRIMessageSignatureIssueDetails,
    StylesheetLoadingIssueDetails,
    StyleSheetLoadingIssueReason,
    UnencodedDigestError,
    UnencodedDigestIssueDetails,
    UserReidentificationIssueDetails,
    UserReidentificationIssueType,
)

__all__ = [
    AffectedCookie,
    AffectedRequest,
    AffectedFrame,
    CookieExclusionReason,
    CookieWarningReason,
    CookieOperation,
    InsightType,
    CookieIssueInsight,
    CookieIssueDetails,
    MixedContentResolutionStatus,
    MixedContentResourceType,
    MixedContentIssueDetails,
    BlockedByResponseReason,
    BlockedByResponseIssueDetails,
    HeavyAdResolutionStatus,
    HeavyAdReason,
    HeavyAdIssueDetails,
    ContentSecurityPolicyViolationType,
    SourceCodeLocation,
    ContentSecurityPolicyIssueDetails,
    SharedArrayBufferIssueType,
    SharedArrayBufferIssueDetails,
    LowTextContrastIssueDetails,
    CorsIssueDetails,
    AttributionReportingIssueType,
    SharedDictionaryError,
    SRIMessageSignatureError,
    UnencodedDigestError,
    AttributionReportingIssueDetails,
    QuirksModeIssueDetails,
    NavigatorUserAgentIssueDetails,
    SharedDictionaryIssueDetails,
    SRIMessageSignatureIssueDetails,
    UnencodedDigestIssueDetails,
    GenericIssueErrorType,
    GenericIssueDetails,
    DeprecationIssueDetails,
    BounceTrackingIssueDetails,
    CookieDeprecationMetadataIssueDetails,
    ClientHintIssueReason,
    FederatedAuthRequestIssueDetails,
    FederatedAuthRequestIssueReason,
    FederatedAuthUserInfoRequestIssueDetails,
    FederatedAuthUserInfoRequestIssueReason,
    ClientHintIssueDetails,
    FailedRequestInfo,
    PartitioningBlobURLInfo,
    PartitioningBlobURLIssueDetails,
    ElementAccessibilityIssueReason,
    ElementAccessibilityIssueDetails,
    StyleSheetLoadingIssueReason,
    StylesheetLoadingIssueDetails,
    PropertyRuleIssueReason,
    PropertyRuleIssueDetails,
    UserReidentificationIssueType,
    UserReidentificationIssueDetails,
    PermissionElementIssueType,
    PermissionElementIssueDetails,
    InspectorIssueCode,
    InspectorIssueDetails,
    IssueId,
    InspectorIssue,
    IssueAdded,
    GetEncodedResponse,
    Disable,
    Enable,
    CheckContrast,
    CheckFormsIssues,
]



from .methods import (
    ClearObjectStore,
    DeleteDatabase,
    DeleteObjectStoreEntries,
    Disable,
    Enable,
    GetMetadata,
    RequestData,
    RequestDatabase,
    RequestDatabaseNames,
)
from .types import DatabaseWithObjectStores, DataEntry, Key, KeyPath, KeyRange, ObjectStore, ObjectStoreIndex

__all__ = [
    DatabaseWithObjectStores,
    ObjectStore,
    ObjectStoreIndex,
    Key,
    KeyRange,
    DataEntry,
    KeyPath,
    ClearObjectStore,
    DeleteDatabase,
    DeleteObjectStoreEntries,
    Disable,
    Enable,
    RequestData,
    GetMetadata,
    RequestDatabase,
    RequestDatabaseNames,
]



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/Tracing/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    TracingMemoryDumpConfig,
    TracingMemoryDumpLevelOfDetail,
    TracingStreamCompression,
    TracingStreamFormat,
    TracingTraceConfig,
    TracingTracingBackend,
)

MemoryDumpConfig = TracingMemoryDumpConfig
TraceConfig = TracingTraceConfig
StreamFormat = TracingStreamFormat
StreamCompression = TracingStreamCompression
MemoryDumpLevelOfDetail = TracingMemoryDumpLevelOfDetail
TracingBackend = TracingTracingBackend



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

Debugger domain exposes JavaScript debugging capabilities. It allows setting and removing
breakpoints, stepping through execution, exploring stack traces, etc.
https://chromedevtools.github.io/devtools-protocol/tot/Debugger/

***************************************************
                    Methods
***************************************************
"""
from __future__ import annotations

from typing import Literal

from cdpkit.protocol._types import (
    Debugger,
    Runtime,
)
from cdpkit.protocol.base import CDPMethod, InputModel, OutputModel


class ContinueToLocationInput(InputModel):

    location: Debugger.Location
    targetCallFrames: Literal['any', 'current'] | None = None


class ContinueToLocation(CDPMethod[None]):
    """ Continues execution until specific location is reached. """

    INPUT_VALIDATOR = ContinueToLocationInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        location: Debugger.Location,
        target_call_frames: Literal['any', 'current'] | None = None
    ):
        super().__init__(
            location=location,
            targetCallFrames=target_call_frames
        )


class Disable(CDPMethod[None]):
    """ Disables debugger for given page. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class EnableInput(InputModel):

    maxScriptsCacheSize: float | None = None  # experimental


class EnableOutput(OutputModel):

    debuggerId: Runtime.UniqueDebuggerId | None = None  # experimental


class Enable(CDPMethod[EnableOutput]):
    """ Enables debugger for the given page. Clients should not assume that the debugging has been
    enabled until the result for this command is received. """

    INPUT_VALIDATOR = EnableInput
    OUTPUT_VALIDATOR = EnableOutput

    def __init__(
        self,
        *,
        max_scripts_cache_size: float | None = None
    ):
        super().__init__(
            maxScriptsCacheSize=max_scripts_cache_size
        )


class EvaluateOnCallFrameInput(InputModel):

    callFrameId: Debugger.CallFrameId
    expression: str
    objectGroup: str | None = None
    includeCommandLineAPI: bool | None = None
    silent: bool | None = None
    returnByValue: bool | None = None
    generatePreview: bool | None = None  # experimental
    throwOnSideEffect: bool | None = None
    timeout: Runtime.TimeDelta | None = None  # experimental


class EvaluateOnCallFrameOutput(OutputModel):

    result: Runtime.RemoteObject
    exceptionDetails: Runtime.ExceptionDetails | None = None


class EvaluateOnCallFrame(CDPMethod[EvaluateOnCallFrameOutput]):
    """ Evaluates expression on a given call frame. """

    INPUT_VALIDATOR = EvaluateOnCallFrameInput
    OUTPUT_VALIDATOR = EvaluateOnCallFrameOutput

    def __init__(
        self,
        *,
        call_frame_id: Debugger.CallFrameId,
        expression: str,
        object_group: str | None = None,
        include_command_line_api: bool | None = None,
        silent: bool | None = None,
        return_by_value: bool | None = None,
        generate_preview: bool | None = None,
        throw_on_side_effect: bool | None = None,
        timeout: Runtime.TimeDelta | None = None
    ):
        super().__init__(
            callFrameId=call_frame_id,
            expression=expression,
            objectGroup=object_group,
            includeCommandLineAPI=include_command_line_api,
            silent=silent,
            returnByValue=return_by_value,
            generatePreview=generate_preview,
            throwOnSideEffect=throw_on_side_effect,
            timeout=timeout
        )


class GetPossibleBreakpointsInput(InputModel):

    start: Debugger.Location
    end: Debugger.Location | None = None
    restrictToFunction: bool | None = None


class GetPossibleBreakpointsOutput(OutputModel):

    locations: list[Debugger.BreakLocation]


class GetPossibleBreakpoints(CDPMethod[GetPossibleBreakpointsOutput]):
    """ Returns possible locations for breakpoint. scriptId in start and end range locations should be
    the same. """

    INPUT_VALIDATOR = GetPossibleBreakpointsInput
    OUTPUT_VALIDATOR = GetPossibleBreakpointsOutput

    def __init__(
        self,
        *,
        start: Debugger.Location,
        end: Debugger.Location | None = None,
        restrict_to_function: bool | None = None
    ):
        super().__init__(
            start=start,
            end=end,
            restrictToFunction=restrict_to_function
        )


class GetScriptSourceInput(InputModel):

    scriptId: Runtime.ScriptId


class GetScriptSourceOutput(OutputModel):

    scriptSource: str
    bytecode: str | None = None


class GetScriptSource(CDPMethod[GetScriptSourceOutput]):
    """ Returns source for the script with given id. """

    INPUT_VALIDATOR = GetScriptSourceInput
    OUTPUT_VALIDATOR = GetScriptSourceOutput

    def __init__(
        self,
        *,
        script_id: Runtime.ScriptId
    ):
        super().__init__(
            scriptId=script_id
        )


class DisassembleWasmModuleInput(InputModel):

    scriptId: Runtime.ScriptId


class DisassembleWasmModuleOutput(OutputModel):

    streamId: str | None = None
    totalNumberOfLines: int
    functionBodyOffsets: list[int]
    chunk: Debugger.WasmDisassemblyChunk


class DisassembleWasmModule(CDPMethod[DisassembleWasmModuleOutput]):  # experimental

    INPUT_VALIDATOR = DisassembleWasmModuleInput
    OUTPUT_VALIDATOR = DisassembleWasmModuleOutput

    def __init__(
        self,
        *,
        script_id: Runtime.ScriptId
    ):
        super().__init__(
            scriptId=script_id
        )


class NextWasmDisassemblyChunkInput(InputModel):

    streamId: str


class NextWasmDisassemblyChunkOutput(OutputModel):

    chunk: Debugger.WasmDisassemblyChunk


class NextWasmDisassemblyChunk(CDPMethod[NextWasmDisassemblyChunkOutput]):  # experimental
    """ Disassemble the next chunk of lines for the module corresponding to the
    stream. If disassembly is complete, this API will invalidate the streamId
    and return an empty chunk. Any subsequent calls for the now invalid stream
    will return errors. """

    INPUT_VALIDATOR = NextWasmDisassemblyChunkInput
    OUTPUT_VALIDATOR = NextWasmDisassemblyChunkOutput

    def __init__(
        self,
        *,
        stream_id: str
    ):
        super().__init__(
            streamId=stream_id
        )


class GetWasmBytecodeInput(InputModel):

    scriptId: Runtime.ScriptId


class GetWasmBytecodeOutput(OutputModel):

    bytecode: str


class GetWasmBytecode(CDPMethod[GetWasmBytecodeOutput]):  # deprecated
    """ This command is deprecated. Use getScriptSource instead. """

    INPUT_VALIDATOR = GetWasmBytecodeInput
    OUTPUT_VALIDATOR = GetWasmBytecodeOutput

    def __init__(
        self,
        *,
        script_id: Runtime.ScriptId
    ):
        super().__init__(
            scriptId=script_id
        )


class GetStackTraceInput(InputModel):

    stackTraceId: Runtime.StackTraceId


class GetStackTraceOutput(OutputModel):

    stackTrace: Runtime.StackTrace


class GetStackTrace(CDPMethod[GetStackTraceOutput]):  # experimental
    """ Returns stack trace with given `stackTraceId`. """

    INPUT_VALIDATOR = GetStackTraceInput
    OUTPUT_VALIDATOR = GetStackTraceOutput

    def __init__(
        self,
        *,
        stack_trace_id: Runtime.StackTraceId
    ):
        super().__init__(
            stackTraceId=stack_trace_id
        )


class Pause(CDPMethod[None]):
    """ Stops on the next JavaScript statement. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class PauseOnAsyncCallInput(InputModel):

    parentStackTraceId: Runtime.StackTraceId


class PauseOnAsyncCall(CDPMethod[None]):  # experimental deprecated

    INPUT_VALIDATOR = PauseOnAsyncCallInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        parent_stack_trace_id: Runtime.StackTraceId
    ):
        super().__init__(
            parentStackTraceId=parent_stack_trace_id
        )


class RemoveBreakpointInput(InputModel):

    breakpointId: Debugger.BreakpointId


class RemoveBreakpoint(CDPMethod[None]):
    """ Removes JavaScript breakpoint. """

    INPUT_VALIDATOR = RemoveBreakpointInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        breakpoint_id: Debugger.BreakpointId
    ):
        super().__init__(
            breakpointId=breakpoint_id
        )


class RestartFrameInput(InputModel):

    callFrameId: Debugger.CallFrameId
    mode: Literal['StepInto'] | None = None  # experimental


class RestartFrameOutput(OutputModel):

    callFrames: list[Debugger.CallFrame]  # deprecated
    asyncStackTrace: Runtime.StackTrace | None = None  # deprecated
    asyncStackTraceId: Runtime.StackTraceId | None = None  # deprecated


class RestartFrame(CDPMethod[RestartFrameOutput]):
    """ Restarts particular call frame from the beginning. The old, deprecated
    behavior of `restartFrame` is to stay paused and allow further CDP commands
    after a restart was scheduled. This can cause problems with restarting, so
    we now continue execution immediatly after it has been scheduled until we
    reach the beginning of the restarted frame.

    To stay back-wards compatible, `restartFrame` now expects a `mode`
    parameter to be present. If the `mode` parameter is missing, `restartFrame`
    errors out.

    The various return values are deprecated and `callFrames` is always empty.
    Use the call frames from the `Debugger#paused` events instead, that fires
    once V8 pauses at the beginning of the restarted function. """

    INPUT_VALIDATOR = RestartFrameInput
    OUTPUT_VALIDATOR = RestartFrameOutput

    def __init__(
        self,
        *,
        call_frame_id: Debugger.CallFrameId,
        mode: Literal['StepInto'] | None = None
    ):
        super().__init__(
            callFrameId=call_frame_id,
            mode=mode
        )


class ResumeInput(InputModel):

    terminateOnResume: bool | None = None


class Resume(CDPMethod[None]):
    """ Resumes JavaScript execution. """

    INPUT_VALIDATOR = ResumeInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        terminate_on_resume: bool | None = None
    ):
        super().__init__(
            terminateOnResume=terminate_on_resume
        )


class SearchInContentInput(InputModel):

    scriptId: Runtime.ScriptId
    query: str
    caseSensitive: bool | None = None
    isRegex: bool | None = None


class SearchInContentOutput(OutputModel):

    result: list[Debugger.SearchMatch]


class SearchInContent(CDPMethod[SearchInContentOutput]):
    """ Searches for given string in script content. """

    INPUT_VALIDATOR = SearchInContentInput
    OUTPUT_VALIDATOR = SearchInContentOutput

    def __init__(
        self,
        *,
        script_id: Runtime.ScriptId,
        query: str,
        case_sensitive: bool | None = None,
        is_regex: bool | None = None
    ):
        super().__init__(
            scriptId=script_id,
            query=query,
            caseSensitive=case_sensitive,
            isRegex=is_regex
        )


class SetAsyncCallStackDepthInput(InputModel):

    maxDepth: int


class SetAsyncCallStackDepth(CDPMethod[None]):
    """ Enables or disables async call stacks tracking. """

    INPUT_VALIDATOR = SetAsyncCallStackDepthInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        max_depth: int
    ):
        super().__init__(
            maxDepth=max_depth
        )


class SetBlackboxExecutionContextsInput(InputModel):

    uniqueIds: list[str]


class SetBlackboxExecutionContexts(CDPMethod[None]):  # experimental
    """ Replace previous blackbox execution contexts with passed ones. Forces backend to skip
    stepping/pausing in scripts in these execution contexts. VM will try to leave blackboxed script by
    performing 'step in' several times, finally resorting to 'step out' if unsuccessful. """

    INPUT_VALIDATOR = SetBlackboxExecutionContextsInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        unique_ids: list[str]
    ):
        super().__init__(
            uniqueIds=unique_ids
        )


class SetBlackboxPatternsInput(InputModel):

    patterns: list[str]
    skipAnonymous: bool | None = None


class SetBlackboxPatterns(CDPMethod[None]):  # experimental
    """ Replace previous blackbox patterns with passed ones. Forces backend to skip stepping/pausing in
    scripts with url matching one of the patterns. VM will try to leave blackboxed script by
    performing 'step in' several times, finally resorting to 'step out' if unsuccessful. """

    INPUT_VALIDATOR = SetBlackboxPatternsInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        patterns: list[str],
        skip_anonymous: bool | None = None
    ):
        super().__init__(
            patterns=patterns,
            skipAnonymous=skip_anonymous
        )


class SetBlackboxedRangesInput(InputModel):

    scriptId: Runtime.ScriptId
    positions: list[Debugger.ScriptPosition]


class SetBlackboxedRanges(CDPMethod[None]):  # experimental
    """ Makes backend skip steps in the script in blackboxed ranges. VM will try leave blacklisted
    scripts by performing 'step in' several times, finally resorting to 'step out' if unsuccessful.
    Positions array contains positions where blackbox state is changed. First interval isn't
    blackboxed. Array should be sorted. """

    INPUT_VALIDATOR = SetBlackboxedRangesInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        script_id: Runtime.ScriptId,
        positions: list[Debugger.ScriptPosition]
    ):
        super().__init__(
            scriptId=script_id,
            positions=positions
        )


class SetBreakpointInput(InputModel):

    location: Debugger.Location
    condition: str | None = None


class SetBreakpointOutput(OutputModel):

    breakpointId: Debugger.BreakpointId
    actualLocation: Debugger.Location


class SetBreakpoint(CDPMethod[SetBreakpointOutput]):
    """ Sets JavaScript breakpoint at a given location. """

    INPUT_VALIDATOR = SetBreakpointInput
    OUTPUT_VALIDATOR = SetBreakpointOutput

    def __init__(
        self,
        *,
        location: Debugger.Location,
        condition: str | None = None
    ):
        super().__init__(
            location=location,
            condition=condition
        )


class SetInstrumentationBreakpointInput(InputModel):

    instrumentation: Literal['beforeScriptExecution', 'beforeScriptWithSourceMapExecution']


class SetInstrumentationBreakpointOutput(OutputModel):

    breakpointId: Debugger.BreakpointId


class SetInstrumentationBreakpoint(CDPMethod[SetInstrumentationBreakpointOutput]):
    """ Sets instrumentation breakpoint. """

    INPUT_VALIDATOR = SetInstrumentationBreakpointInput
    OUTPUT_VALIDATOR = SetInstrumentationBreakpointOutput

    def __init__(
        self,
        *,
        instrumentation: Literal['beforeScriptExecution', 'beforeScriptWithSourceMapExecution']
    ):
        super().__init__(
            instrumentation=instrumentation
        )


class SetBreakpointByUrlInput(InputModel):

    lineNumber: int
    url: str | None = None
    urlRegex: str | None = None
    scriptHash: str | None = None
    columnNumber: int | None = None
    condition: str | None = None


class SetBreakpointByUrlOutput(OutputModel):

    breakpointId: Debugger.BreakpointId
    locations: list[Debugger.Location]


class SetBreakpointByUrl(CDPMethod[SetBreakpointByUrlOutput]):
    """ Sets JavaScript breakpoint at given location specified either by URL or URL regex. Once this
    command is issued, all existing parsed scripts will have breakpoints resolved and returned in
    `locations` property. Further matching script parsing will result in subsequent
    `breakpointResolved` events issued. This logical breakpoint will survive page reloads. """

    INPUT_VALIDATOR = SetBreakpointByUrlInput
    OUTPUT_VALIDATOR = SetBreakpointByUrlOutput

    def __init__(
        self,
        *,
        line_number: int,
        url: str | None = None,
        url_regex: str | None = None,
        script_hash: str | None = None,
        column_number: int | None = None,
        condition: str | None = None
    ):
        super().__init__(
            lineNumber=line_number,
            url=url,
            urlRegex=url_regex,
            scriptHash=script_hash,
            columnNumber=column_number,
            condition=condition
        )


class SetBreakpointOnFunctionCallInput(InputModel):

    objectId: Runtime.RemoteObjectId
    condition: str | None = None


class SetBreakpointOnFunctionCallOutput(OutputModel):

    breakpointId: Debugger.BreakpointId


class SetBreakpointOnFunctionCall(CDPMethod[SetBreakpointOnFunctionCallOutput]):  # experimental
    """ Sets JavaScript breakpoint before each call to the given function.
    If another function was created from the same source as a given one,
    calling it will also trigger the breakpoint. """

    INPUT_VALIDATOR = SetBreakpointOnFunctionCallInput
    OUTPUT_VALIDATOR = SetBreakpointOnFunctionCallOutput

    def __init__(
        self,
        *,
        object_id: Runtime.RemoteObjectId,
        condition: str | None = None
    ):
        super().__init__(
            objectId=object_id,
            condition=condition
        )


class SetBreakpointsActiveInput(InputModel):

    active: bool


class SetBreakpointsActive(CDPMethod[None]):
    """ Activates / deactivates all breakpoints on the page. """

    INPUT_VALIDATOR = SetBreakpointsActiveInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        active: bool
    ):
        super().__init__(
            active=active
        )


class SetPauseOnExceptionsInput(InputModel):

    state: Literal['none', 'caught', 'uncaught', 'all']


class SetPauseOnExceptions(CDPMethod[None]):
    """ Defines pause on exceptions state. Can be set to stop on all exceptions, uncaught exceptions,
    or caught exceptions, no exceptions. Initial pause on exceptions state is `none`. """

    INPUT_VALIDATOR = SetPauseOnExceptionsInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        state: Literal['none', 'caught', 'uncaught', 'all']
    ):
        super().__init__(
            state=state
        )


class SetReturnValueInput(InputModel):

    newValue: Runtime.CallArgument


class SetReturnValue(CDPMethod[None]):  # experimental
    """ Changes return value in top frame. Available only at return break position. """

    INPUT_VALIDATOR = SetReturnValueInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        new_value: Runtime.CallArgument
    ):
        super().__init__(
            newValue=new_value
        )


class SetScriptSourceInput(InputModel):

    scriptId: Runtime.ScriptId
    scriptSource: str
    dryRun: bool | None = None
    allowTopFrameEditing: bool | None = None  # experimental


class SetScriptSourceOutput(OutputModel):

    callFrames: list[Debugger.CallFrame] | None = None  # deprecated
    stackChanged: bool | None = None  # deprecated
    asyncStackTrace: Runtime.StackTrace | None = None  # deprecated
    asyncStackTraceId: Runtime.StackTraceId | None = None  # deprecated
    status: Literal['Ok', 'CompileError', 'BlockedByActiveGenerator', 'BlockedByActiveFunction', 'BlockedByTopLevelEsModuleChange'] | None = None  # experimental
    exceptionDetails: Runtime.ExceptionDetails | None = None


class SetScriptSource(CDPMethod[SetScriptSourceOutput]):
    """ Edits JavaScript source live.

    In general, functions that are currently on the stack can not be edited with
    a single exception: If the edited function is the top-most stack frame and
    that is the only activation of that function on the stack. In this case
    the live edit will be successful and a `Debugger.restartFrame` for the
    top-most function is automatically triggered. """

    INPUT_VALIDATOR = SetScriptSourceInput
    OUTPUT_VALIDATOR = SetScriptSourceOutput

    def __init__(
        self,
        *,
        script_id: Runtime.ScriptId,
        script_source: str,
        dry_run: bool | None = None,
        allow_top_frame_editing: bool | None = None
    ):
        super().__init__(
            scriptId=script_id,
            scriptSource=script_source,
            dryRun=dry_run,
            allowTopFrameEditing=allow_top_frame_editing
        )


class SetSkipAllPausesInput(InputModel):

    skip: bool


class SetSkipAllPauses(CDPMethod[None]):
    """ Makes page not interrupt on any pauses (breakpoint, exception, dom exception etc). """

    INPUT_VALIDATOR = SetSkipAllPausesInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        skip: bool
    ):
        super().__init__(
            skip=skip
        )


class SetVariableValueInput(InputModel):

    scopeNumber: int
    variableName: str
    newValue: Runtime.CallArgument
    callFrameId: Debugger.CallFrameId


class SetVariableValue(CDPMethod[None]):
    """ Changes value of variable in a callframe. Object-based scopes are not supported and must be
    mutated manually. """

    INPUT_VALIDATOR = SetVariableValueInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        scope_number: int,
        variable_name: str,
        new_value: Runtime.CallArgument,
        call_frame_id: Debugger.CallFrameId
    ):
        super().__init__(
            scopeNumber=scope_number,
            variableName=variable_name,
            newValue=new_value,
            callFrameId=call_frame_id
        )


class StepIntoInput(InputModel):

    breakOnAsyncCall: bool | None = None  # experimental
    skipList: list[Debugger.LocationRange] | None = None  # experimental


class StepInto(CDPMethod[None]):
    """ Steps into the function call. """

    INPUT_VALIDATOR = StepIntoInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        break_on_async_call: bool | None = None,
        skip_list: list[Debugger.LocationRange] | None = None
    ):
        super().__init__(
            breakOnAsyncCall=break_on_async_call,
            skipList=skip_list
        )


class StepOut(CDPMethod[None]):
    """ Steps out of the function call. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class StepOverInput(InputModel):

    skipList: list[Debugger.LocationRange] | None = None  # experimental


class StepOver(CDPMethod[None]):
    """ Steps over the statement. """

    INPUT_VALIDATOR = StepOverInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        skip_list: list[Debugger.LocationRange] | None = None
    ):
        super().__init__(
            skipList=skip_list
        )



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

A domain for letting clients substitute browser's network layer with client code.
https://chromedevtools.github.io/devtools-protocol/tot/Fetch/

***************************************************
                    Types
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    FetchAuthChallenge,
    FetchAuthChallengeResponse,
    FetchHeaderEntry,
    FetchRequestId,
    FetchRequestPattern,
    FetchRequestStage,
)

RequestId = FetchRequestId
RequestStage = FetchRequestStage
RequestPattern = FetchRequestPattern
HeaderEntry = FetchHeaderEntry
AuthChallenge = FetchAuthChallenge
AuthChallengeResponse = FetchAuthChallengeResponse



from .events import LoadComplete, NodesUpdated
from .methods import (
    Disable,
    Enable,
    GetAXNodeAndAncestors,
    GetChildAXNodes,
    GetFullAXTree,
    GetPartialAXTree,
    GetRootAXNode,
    QueryAXTree,
)
from .types import (
    AXNode,
    AXNodeId,
    AXProperty,
    AXPropertyName,
    AXRelatedNode,
    AXValue,
    AXValueNativeSourceType,
    AXValueSource,
    AXValueSourceType,
    AXValueType,
)

__all__ = [
    AXNodeId,
    AXValueType,
    AXValueSourceType,
    AXValueNativeSourceType,
    AXValueSource,
    AXRelatedNode,
    AXProperty,
    AXValue,
    AXPropertyName,
    AXNode,
    LoadComplete,
    NodesUpdated,
    Disable,
    Enable,
    GetPartialAXTree,
    GetFullAXTree,
    GetRootAXNode,
    GetAXNodeAndAncestors,
    GetChildAXNodes,
    QueryAXTree,
]



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.

This domain allows configuring virtual Bluetooth devices to test
the web-bluetooth API.
https://chromedevtools.github.io/devtools-protocol/tot/BluetoothEmulation/

***************************************************
                    Events
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    BluetoothEmulation,
)
from cdpkit.protocol.base import CDPEvent


class GattOperationReceived(CDPEvent):
    """ Event for when a GATT operation of |type| to the peripheral with |address|
    happened. """

    address: str
    type: BluetoothEmulation.GATTOperationType


class CharacteristicOperationReceived(CDPEvent):
    """ Event for when a characteristic operation of |type| to the characteristic
    respresented by |characteristicId| happened. |data| and |writeType| is
    expected to exist when |type| is write. """

    characteristicId: str
    type: BluetoothEmulation.CharacteristicOperationType
    data: str | None = None
    writeType: BluetoothEmulation.CharacteristicWriteType | None = None


class DescriptorOperationReceived(CDPEvent):
    """ Event for when a descriptor operation of |type| to the descriptor
    respresented by |descriptorId| happened. |data| is expected to exist when
    |type| is write. """

    descriptorId: str
    type: BluetoothEmulation.DescriptorOperationType
    data: str | None = None



"""
This file is generated by generator/run.py based on the Chrome DevTools Protocol.


https://chromedevtools.github.io/devtools-protocol/tot/DeviceAccess/

***************************************************
                    Methods
***************************************************
"""
from __future__ import annotations

from cdpkit.protocol._types import (
    DeviceAccess,
)
from cdpkit.protocol.base import CDPMethod, InputModel


class Enable(CDPMethod[None]):
    """ Enable events in this domain. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class Disable(CDPMethod[None]):
    """ Disable events in this domain. """

    INPUT_VALIDATOR = None
    OUTPUT_VALIDATOR = None


class SelectPromptInput(InputModel):

    id: DeviceAccess.RequestId
    deviceId: DeviceAccess.DeviceId


class SelectPrompt(CDPMethod[None]):
    """ Select a device in response to a DeviceAccess.deviceRequestPrompted event. """

    INPUT_VALIDATOR = SelectPromptInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        id_: DeviceAccess.RequestId,
        device_id: DeviceAccess.DeviceId
    ):
        super().__init__(
            id=id_,
            deviceId=device_id
        )


class CancelPromptInput(InputModel):

    id: DeviceAccess.RequestId


class CancelPrompt(CDPMethod[None]):
    """ Cancel a prompt in response to a DeviceAccess.deviceRequestPrompted event. """

    INPUT_VALIDATOR = CancelPromptInput
    OUTPUT_VALIDATOR = None

    def __init__(
        self,
        *,
        id_: DeviceAccess.RequestId
    ):
        super().__init__(
            id=id_
        )
